# v0.2.1 (2020-09-04)

- Show OF controllers in graphviz
- Check if ACLs are empty
- Updated faucetconfrpc

# v0.2.0 (2020-08-31)

- Initial offering. Supports creating/deleting VMs and/or containers attached to OVS and wired to Faucet/Gauge.
- Leverages Dovesnap, Open vSwitch, libvirt/kvm, Docker, and FaucetConfRPC among other things to accomplish easy management of containers and VMs in both virtual and hardware environments controlled by SDN.
